我为这个产品命名为  **`TermiVis`** ，意为 "终端视觉" (Terminal Vision)，凸显其核心能力。

---

### **产品需求文档 (PRD): TermiVis**

| 项目               | 详情                                                    |
| ------------------ | ------------------------------------------------------- |
| **产品名称** | **TermiVis**(The Visual Bridge for Your Terminal) |
| **内部代号** | `image-mcp-server`                                    |
| **文档版本** | `1.0.0`                                               |
| **状态**     | `定稿`                                                |
| **日期**     | `2025年7月23日`                                       |
| **负责人**   | `[填写负责人姓名]`                                    |

### 1. 项目概述

#### 1.1. 问题背景

当前主流的终端原生 AI 编程工具（如 Claude Code, Gemini CLI）在多模态能力上存在显著短板，主要体现在：

* **仅支持文本：** 无法直接处理或理解图片、UI 截图等视觉内容。
* **工作流中断：** 开发者在需要分析视觉信息时，必须离开终端环境，切换到其他工具，严重影响了开发效率和专注度。
* **方案缺失：** 市场缺乏一个统一、标准的终端多模态输入解决方案。

#### 1.2. 解决方案与目标

本项目旨在开发一个名为 **TermiVis** 的后台服务。它基于 **MCP (Model Context Protocol)** 协议，作为一个标准化的多模态服务层，专门为终端编程工具提供强大的图片理解能力。

**核心目标：**

* **赋能终端：** 让所有兼容 MCP 协议的终端工具都能无缝集成视觉分析功能。
* **统一标准：** 提供一个稳定、可扩展的图片识别后端服务。
* **提升效率：** 打造一个不离开终端的、沉浸式的图文交互开发体验。

### 2. 功能需求

#### 2.1. 图片处理模块 (`image_handler.py`)

**功能描述：** 负责所有图片输入的接收、验证、预处理和编码。

| 功能点                 | 技术要求                                                                                                                                                                                          |
| ---------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| **多格式支持**   | 必须支持 `PNG`,`JPG/JPEG`,`WEBP`,`GIF`,`BMP`格式。                                                                                                                                      |
| **多源输入**     | -**本地路径** ：`mcp --image /path/to/image.png "..."<br>` - **远程 URL** ：`mcp --image https://.../image.jpg "..."<br>` - **剪贴板** ：自动检测并读取系统剪贴板中的图片。 |
| **自动编码**     | 所有输入的图片最终都将转换为符合 `data:[MIME_type];base64,...`格式的字符串。                                                                                                                    |
| **文件大小限制** | 硬性限制单张图片源文件大小不超过**10MB** 。                                                                                                                                                 |
| **智能压缩**     | 当图片文件大小超过**5MB**时，使用 `Pillow`库自动将其压缩到合适尺寸（例如，最长边不超过 2048 像素），以优化 API 调用速度和成本。                                                           |
| **批量处理**     | 支持在单次请求中处理多张图片，上限为**5**张。                                                                                                                                               |

#### 2.2. API 集成模块 (`api_client.py`)

**功能描述：** 封装对上海人工智能实验室 InternVL API 的所有调用逻辑，提供稳定可靠的模型能力。

| 功能点               | 技术要求                                                                                                                                                                                                                                                                |
| -------------------- | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| **配置化管理** | API 相关配置（端点、模型、默认参数）应在独立的配置文件或 Pydantic 模型中统一管理，便于维护。                                                                                                                                                                            |
| **认证安全**   | `Authorization`Token 必须通过环境变量 (`INTERNVL_API_KEY`) 读取，严禁硬编码在代码中。                                                                                                                                                                               |
| **错误处理**   | -**网络超时重试** ：使用指数退避策略（Exponential Backoff）进行**3**次自动重试。``- **速率限制** ：遵循 API 返回的速率限制头，实现客户端请求队列和延迟。``- **异常分类** ：清晰地捕获并向客户端报告网络错误、认证错误（401/403）、模型错误（5xx）等。 |
| **降级策略**   | **（可选，V2.0 规划）**当 InternVL API 不可用或响应失败时，可降级调用本地 OCR 模型（如 `Tesseract`），提供基础的文字提取能力。                                                                                                                                        |

#### 2.3. MCP 协议实现模块 (`server.py`, `tools.py`)

**功能描述：** 实现标准的 MCP 服务器，对外暴露工具和服务。

| 功能点               | 技术要求                                                                                                                                                                                                                                                                                                                                                                       |
| -------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------ |
| **MCP 服务器** | 基于 `mcp`官方 SDK 的 `mcp.server.Server`类进行构建。                                                                                                                                                                                                                                                                                                                      |
| **流式响应**   | 所有与模型的交互必须支持**SSE (Server-Sent Events)** ，以实现打字机式的实时流式输出，提升用户体验。                                                                                                                                                                                                                                                                      |
| **会话管理**   | 能够维护多轮对话的上下文历史，支持在对话中引用之前上传过的图片。                                                                                                                                                                                                                                                                                                               |
| **工具定义**   | 在 `tools.py`中定义并向 MCP 客户端注册以下核心工具：`<br>` -`analyze_image`: 对单张或多张图片进行综合性分析。`<br>` -`describe_image`: 详细描述图片中的场景、人物、情感等。`<br>` -`extract_text`: 调用 OCR 能力，提取图片中的所有文字。`<br>` -`compare_images`: 对比两张图片的异同点。`<br>` -`identify_objects`: 识别并列出图片中的主要物体及其位置。 |

### 3. 技术架构与规格

#### 3.1. 技术选型

* **开发语言** : Python 3.9+
* **包管理工具** : `uv` (用于环境创建和依赖安装)
* **核心框架/库** : `mcp`, `fastapi`, `uvicorn`, `httpx`, `pillow`, `pydantic`, `typer`

#### 3.2. 项目结构规范

```
image-mcp-server/
├── pyproject.toml          # uv 项目配置与依赖管理
├── README.md               # 项目说明文档
├── .env.example            # 环境变量示例文件
├── src/
│   └── image_mcp/
│       ├── __init__.py
│       ├── server.py       # FastAPI & MCP 服务器主入口
│       ├── image_handler.py # 图片处理模块
│       ├── api_client.py   # InternVL API 客户端
│       ├── tools.py        # MCP 工具定义
│       └── config.py       # Pydantic 配置模型
└── tests/                    # 单元测试与集成测试
```

#### 3.3. 依赖配置 (`pyproject.toml`)

**Ini, TOML**

```
[project]
name = "image-mcp-server"
version = "1.0.0"
description = "TermiVis: A powerful MCP server for image analysis using InternVL."
dependencies = [
    "mcp>=1.0.0",
    "fastapi>=0.110.0",
    "uvicorn[standard]>=0.29.0",
    "httpx[http2]>=0.27.0",
    "pillow>=10.0.0",
    "pydantic>=2.7.0",
    "pydantic-settings>=2.2.0",
    "python-dotenv>=1.0.0",
    "typer>=0.9.0",
    "tenacity>=8.2.0"  # 用于实现重试逻辑
]

[build-system]
requires = ["hatchling"]
build-backend = "hatchling.build"
```

### 4. 核心实现逻辑与代码示例

#### 4.1. API 配置模型 (`config.py`)

**Python**

```
from pydantic_settings import BaseSettings
from pydantic import Field

class Settings(BaseSettings):
    internvl_api_key: str = Field(..., env="INTERNVL_API_KEY")
    internvl_api_endpoint: str = "https://chat.intern-ai.org.cn/api/v1/chat/completions"
    default_model: str = "internvl3-latest"
    default_temperature: float = 0.7
    default_top_p: float = 0.9
    max_tokens: int = 2048

    class Config:
        env_file = ".env"
        extra = "ignore"

settings = Settings()
```

#### 4.2. API 客户端示例 (`api_client.py`)

**Python**

```
import httpx
from tenacity import retry, stop_after_attempt, wait_exponential
from .config import settings

class InternVLClient:
    def __init__(self):
        self.api_key = settings.internvl_api_key
        self.endpoint = settings.internvl_api_endpoint

    @retry(wait=wait_exponential(multiplier=1, min=2, max=60), stop=stop_after_attempt(3))
    async def stream_completion(self, messages: list):
        headers = {
            "Authorization": f"Bearer {self.api_key}",
            "Content-Type": "application/json",
            "Accept": "text/event-stream"
        }
        json_data = {
            "model": settings.default_model,
            "messages": messages,
            "temperature": settings.default_temperature,
            "top_p": settings.default_top_p,
            "max_tokens": settings.max_tokens,
            "stream": True
        }

        async with httpx.AsyncClient(timeout=180.0) as client:
            async with client.stream("POST", self.endpoint, headers=headers, json=json_data) as response:
                response.raise_for_status()
                async for chunk in response.aiter_text():
                    yield chunk
```

### 5. 开发计划与里程碑

#### 第一阶段：核心功能开发 (3-4 天)

* [ ] **任务1:** 环境搭建：使用 `uv` 初始化项目结构，配置 `pyproject.toml`。
* [ ] **任务2:** 图片处理模块 (`image_handler.py`)：实现多源输入、格式验证、压缩和 Base64 编码。
* [ ] **任务3:** API 客户端模块 (`api_client.py`)：封装 `httpx` 调用，实现配置化管理和重试逻辑。
* [ ] **任务4:** 编写单元测试，确保以上模块功能稳定。

#### 第二阶段：MCP 集成与实现 (2-3 天)

* [ ] **任务5:** 搭建基础 `FastAPI` 和 `MCP` 服务器框架 (`server.py`)。
* [ ] **任务6:** 定义并注册所有 MCP 工具 (`tools.py`)，并将工具逻辑与后端模块连接。
* [ ] **任务7:** 实现完整的 SSE 流式响应，将 API Client 的输出正确传递给 MCP 客户端。
* [ ] **任务8:** 进行本地集成测试，确保 MCP 工具可被正常调用。

#### 第三阶段：优化、文档与测试 (2-3 天)

* [ ] **任务9:** 性能调优，特别是图片压缩和并发请求处理。
* [ ] **任务10:** 完善日志记录和错误处理，提供更友好的错误提示。
* [ ] **任务11:** 编写详细的 `README.md`，包括安装、配置和使用指南。
* [ ] **任务12:** 与 `Claude Code` 或其他 MCP 客户端进行端到端集成测试。

### 6. 验收标准

| 类别               | 验收标准                                                                                                                                                                                                                |
| ------------------ | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| **功能验收** | [ ] 所有在 `tools.py`中定义的工具均可被成功调用。``[ ] 成功与至少一个主流 MCP 客户端（如 Claude Code）集成。``[ ] 在正常网络条件下，API 调用成功率 > 98%。``[ ] 从接收请求到返回首个 token 的时间（P95）应小于 5 秒。 |
| **技术验收** | [ ] 代码测试覆盖率 > 80%。``[ ] 通过 MCP 官方协议验证工具的兼容性测试。``[ ] 能够稳定处理至少 5 个并发请求。``[ ] 服务长时间运行后，内存使用稳定，无明显泄漏。                                                          |
| **用户体验** | [ ] 命令行或客户端返回的错误信息清晰、具体、易于理解。``[ ] 流式输出平滑，无明显卡顿。``[ ] 配置过程简单，通过一个 `.env`文件即可完成核心配置。                                                                       |

### 7. 风险评估与应对

| 风险类别             | 风险描述                                          | 应对策略                                                                                                        |
| -------------------- | ------------------------------------------------- | --------------------------------------------------------------------------------------------------------------- |
| **技术风险**   | InternVL API 出现故障或性能下降。                 | 1. 实现彻底的超时和重试机制。``2. 增加详细的服务状态日志。``3.**（长期）**探索备用模型或本地 OCR 作为降级方案。 |
| **业务风险**   | API 调用频率或Token数量超出配额。                 | 1. 在客户端实现请求队列，主动控制请求速率。``2. 监控 Token 使用情况，提供用量告警。                             |
| **兼容性风险** | 不同终端环境或 MCP 客户端对协议的实现有细微差异。 | 1. 严格遵循 MCP 官方文档规范。``2. 在多种环境（macOS, Linux, Windows/WSL）下进行广泛测试。                      |
